Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/vax/boot rename local index() to strchr()



details:   https://anonhg.NetBSD.org/src/rev/4acb78c26dbf
branches:  trunk
changeset: 554734:4acb78c26dbf
user:      jdolecek <jdolecek%NetBSD.org@localhost>
date:      Sat Nov 01 13:02:04 2003 +0000

description:
rename local index() to strchr()

diffstat:

 sys/arch/vax/boot/boot/boot.c     |  6 +++---
 sys/arch/vax/boot/boot/devopen.c  |  6 +++---
 sys/arch/vax/boot/boot/vaxstand.h |  4 ++--
 sys/arch/vax/boot/common/str.S    |  6 +++---
 4 files changed, 11 insertions(+), 11 deletions(-)

diffs (93 lines):

diff -r b98330d0a63e -r 4acb78c26dbf sys/arch/vax/boot/boot/boot.c
--- a/sys/arch/vax/boot/boot/boot.c     Sat Nov 01 12:56:32 2003 +0000
+++ b/sys/arch/vax/boot/boot/boot.c     Sat Nov 01 13:02:04 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: boot.c,v 1.20 2003/08/07 16:30:02 agc Exp $ */
+/*     $NetBSD: boot.c,v 1.21 2003/11/01 13:02:04 jdolecek Exp $ */
 /*-
  * Copyright (c) 1982, 1986 The Regents of the University of California.
  * All rights reserved.
@@ -174,7 +174,7 @@
                if (c[0] == 0)
                        continue;
 
-               if ((d = index(c, ' ')))
+               if ((d = strchr(c, ' ')))
                        *d++ = 0;
 
                while (v->namn) {
@@ -208,7 +208,7 @@
 
                if (*arg != '-') {
                        fn = arg;
-                       if ((arg = index(arg, ' '))) {
+                       if ((arg = strchr(arg, ' '))) {
                                *arg++ = 0;
                                while (*arg == ' ')
                                        arg++;
diff -r b98330d0a63e -r 4acb78c26dbf sys/arch/vax/boot/boot/devopen.c
--- a/sys/arch/vax/boot/boot/devopen.c  Sat Nov 01 12:56:32 2003 +0000
+++ b/sys/arch/vax/boot/boot/devopen.c  Sat Nov 01 13:02:04 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: devopen.c,v 1.10 2002/05/24 21:40:59 ragge Exp $ */
+/*     $NetBSD: devopen.c,v 1.11 2003/11/01 13:02:04 jdolecek Exp $ */
 /*
  * Copyright (c) 1997 Ludd, University of Lule}, Sweden.
  * All rights reserved.
@@ -78,7 +78,7 @@
                        dp = devsw + i;
 
        x = 0;
-       if ((s = index((char *)fname, '('))) {
+       if ((s = strchr((char *)fname, '('))) {
                *s++ = 0;
 
                for (i = 0, dp = devsw; i < ndevs; i++, dp++)
@@ -94,7 +94,7 @@
                        return -1;
                }
                dev = cnvtab[i];
-               if ((c = index(s, ')')) == 0)
+               if ((c = strchr(s, ')')) == 0)
                        goto usage;
 
                *c++ = 0;
diff -r b98330d0a63e -r 4acb78c26dbf sys/arch/vax/boot/boot/vaxstand.h
--- a/sys/arch/vax/boot/boot/vaxstand.h Sat Nov 01 12:56:32 2003 +0000
+++ b/sys/arch/vax/boot/boot/vaxstand.h Sat Nov 01 13:02:04 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: vaxstand.h,v 1.5 2000/06/15 19:53:23 ragge Exp $ */
+/*     $NetBSD: vaxstand.h,v 1.6 2003/11/01 13:02:04 jdolecek Exp $ */
 /*
  * Copyright (c) 1994 Ludd, University of Lule}, Sweden.
  * All rights reserved.
@@ -50,7 +50,7 @@
 
 struct netif_driver;
 
-char *index(char *, int);
+char *strchr(char *, int);
 int net_devinit(struct open_file *f, struct netif_driver *drv, u_char *eaddr);
 
 /* device calls */
diff -r b98330d0a63e -r 4acb78c26dbf sys/arch/vax/boot/common/str.S
--- a/sys/arch/vax/boot/common/str.S    Sat Nov 01 12:56:32 2003 +0000
+++ b/sys/arch/vax/boot/common/str.S    Sat Nov 01 13:02:04 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: str.S,v 1.3 2003/10/07 12:01:27 ragge Exp $ */
+/*     $NetBSD: str.S,v 1.4 2003/11/01 13:02:04 jdolecek Exp $ */
 /*
  * Copyright (c) 1996 Ludd, University of Lule}, Sweden.
  * All rights reserved.
@@ -56,9 +56,9 @@
 1:     ret
 
 /*
  * index() small and easy.
  */
-ENTRY(index, 0)
+ENTRY(strchr, 0)
        movq    4(%ap),%r0
 1:     cmpb    (%r0), 8(%ap)
        beql    2f
@@ -56,9 +56,9 @@
 
 /*
- * index() small and easy.
+ * strchr() small and easy.
  */



Home | Main Index | Thread Index | Old Index